@@ -82,8 +82,6 @@ class DummyFileGenerator:
         :param data_files_location:
         :return:
         """
-        data_files = None
-
         try:
             data_files = [f for f in os.listdir(data_files_location) if
                           os.path.isfile(os.path.join(data_files_location, f))
@@ -92,6 +90,9 @@ class DummyFileGenerator:
             raise DummyFileGeneratorException(f'Cannot list data_files, '
                                               f'OSError: {os_err}')
 
+        if not data_files:
+            raise DummyFileGeneratorException(f'No data_files in {data_files_location}')
+
         for data_file in data_files:
             setattr(self, 'data_file_' + data_file.replace('.txt', ''),
                     get_data_file_content_list_with_item_count(data_file,
@@ -200,7 +201,12 @@ class DummyFileGenerator:
 
         for column in columns:
             column = column.strip("'")
-            _val, _len = DummyFileGenerator.__getattribute__(self, 'data_file_' + column)
+            try:
+                _val, _len = DummyFileGenerator.__getattribute__(self, 'data_file_' + column)
+            except AttributeError as attr_err:
+                raise DummyFileGeneratorException(f'Cannot find corresponding data_file for '
+                                                  f'column {column}, Attribute Error: {attr_err}')
+
             value = _val[randint(0, _len)]
             row.append(value)
         row = csv_value_separator.join(row)
@@ -220,7 +226,12 @@ class DummyFileGenerator:
         for index, column in enumerate(columns):
             column = column.strip("'")
             whitespace = int(column_lengths[index])
-            _val, _len = DummyFileGenerator.__getattribute__(self, 'data_file_' + column)
+            try:
+                _val, _len = DummyFileGenerator.__getattribute__(self, 'data_file_' + column)
+            except AttributeError as attr_err:
+                raise DummyFileGeneratorException(f'Cannot find corresponding data_file for '
+                                                  f'column {column}, Attribute Error: {attr_err}')
+
             value = _val[randint(0, _len)]
             if whitespace < len(value):
                 LOGGER.error('Column value %s is longer then expected '
@@ -304,8 +315,9 @@ class DummyFileGenerator:
 
             execution_end_time = datetime.now()
             output_file_size = output_file.tell()
-            duration = (execution_end_time - execution_start_time).seconds
-            duration = str(duration / 60) + ' min.' if duration > 1000 else str(duration) + ' sec.'
+            _duration = (execution_end_time - execution_start_time).seconds
+            duration = str(_duration / 60) + ' min.' if _duration > 1000 \
+                else str(_duration) + ' sec.'
 
             LOGGER.info('File %s processing finished at %s', generated_file_path,
                         execution_end_time)
